==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ColumnSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { ColumnSeriesDescription } from "./ColumnSeriesDescription";
/**
 * @hidden
 */
var ColumnSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnSeriesDescriptionMetadata, _super);
    function ColumnSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnSeriesDescriptionMetadata.b = function (a) {
        if (ColumnSeriesDescriptionMetadata.a == null) {
            ColumnSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnSeriesDescriptionMetadata.c(ColumnSeriesDescriptionMetadata.a);
        }
        if (a.k(ColumnSeriesDescriptionMetadata.a)) {
            return;
        }
        a.ab(ColumnSeriesDescriptionMetadata.a);
    };
    ColumnSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
        a.item("ConsolidatedColumnVerticalPosition", "ExportedType:string:ConsolidatedItemsPosition");
        a.item("ConsolidatedColumnVerticalPosition@names", "Minimum;Maximum;Median;RelativeMinimum;RelativeMaximum");
    };
    ColumnSeriesDescriptionMetadata.d = function (a) {
        ColumnSeriesDescriptionMetadata.b(a);
        a.ad("ColumnSeries", function () { return new ColumnSeriesDescription(); });
        a.ac("ColumnSeries", ColumnSeriesDescriptionMetadata.a);
    };
    ColumnSeriesDescriptionMetadata.$t = markType(ColumnSeriesDescriptionMetadata, 'ColumnSeriesDescriptionMetadata');
    ColumnSeriesDescriptionMetadata.a = null;
    return ColumnSeriesDescriptionMetadata;
}(Base));
export { ColumnSeriesDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/ColumnSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { ColumnSeriesDescription } from "./ColumnSeriesDescription";
/**
 * @hidden
 */
var ColumnSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnSeriesDescriptionMetadata, _super);
    function ColumnSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnSeriesDescriptionMetadata.b = function (a) {
        if (ColumnSeriesDescriptionMetadata.a == null) {
            ColumnSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnSeriesDescriptionMetadata.c(ColumnSeriesDescriptionMetadata.a);
        }
        if (a.k(ColumnSeriesDescriptionMetadata.a)) {
            return;
        }
        a.ac(ColumnSeriesDescriptionMetadata.a);
    };
    ColumnSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
        a.item("ConsolidatedColumnVerticalPosition", "ExportedType:string:ConsolidatedItemsPosition");
        a.item("ConsolidatedColumnVerticalPosition@names", "Minimum;Maximum;Median;RelativeMinimum;RelativeMaximum");
    };
    ColumnSeriesDescriptionMetadata.d = function (a) {
        ColumnSeriesDescriptionMetadata.b(a);
        a.ae("ColumnSeries", function () { return new ColumnSeriesDescription(); });
        a.ad("ColumnSeries", ColumnSeriesDescriptionMetadata.a);
    };
    ColumnSeriesDescriptionMetadata.$t = markType(ColumnSeriesDescriptionMetadata, 'ColumnSeriesDescriptionMetadata');
    ColumnSeriesDescriptionMetadata.a = null;
    return ColumnSeriesDescriptionMetadata;
}(Base));
export { ColumnSeriesDescriptionMetadata };
